<!--
SPDX-FileCopyrightText: © 2024 nosludge <https://github.com/nosludge>
SPDX-FileContributor: szymonmaszke <github@maszke.co>

SPDX-License-Identifier: Apache-2.0
-->

# Tests of cogeol

<!-- Describe your testing here -->
